@@ -308,13 +308,12 @@ def setup(args):
 
 def main(args):
     cfg = setup(args)
-
     register_coco_instances("train_dataset", {},
-                            f"{args.train_coco_json}",
-                            f"{args.train_images}", )
+                            f"{cfg.DATASETS.TRAIN[1]}",
+                            f"{cfg.DATASETS.TRAIN[2]}", )
     register_coco_instances("test_dataset", {},
-                            f"{args.test_coco_json}",
-                            f"{args.test_images}", )
+                            f"{cfg.DATASETS.TEST[1]}",
+                            f"{cfg.DATASETS.TEST[2]}", )
     if args.eval_only:
         model = Trainer.build_model(cfg)
         DetectionCheckpointer(model, save_dir=cfg.OUTPUT_DIR).resume_or_load(
